
# Slot: value


example value

URI: [meta:value](https://w3id.org/biolink/biolinkml/meta/value)

## Domain and Range

[Example](Example.md) ->  <sub>OPT</sub> [String](String.md)

## Parents


## Children


## Used by

 * [Example](Example.md)
